==> qlevar_router-1.7.0.tar.gz: lib/src/controllers/middleware_controller.dart <==
import 'package:flutter/material.dart';

import '../../qlevar_router.dart';
import '../routes/qroute_internal.dart';

class MiddlewareController {
  final QRouteInternal route;
  MiddlewareController(this.route);

  Future<String?> runRedirect() async {
    final path = route.getLastActivePath();
    for (var middle in route.route.middleware!) {
      final result = await middle.redirectGuard(path);
      if (result != null) {
        return result;
      }
    }
    return null;
  }

  Future<QNameRedirect?> runRedirectName() async {
    final path = route.getLastActivePath();
    for (var middle in route.route.middleware!) {
      final result = await middle.redirectGuardToName(path);
      if (result != null) {
        return result;
      }
    }
    return null;
  }

  Future runOnEnter() async {
    if (!route.hasMiddleware) {
      return;
    }
    for (var middle in route.route.middleware!) {
      await middle.onEnter();
    }
  }

  Future runOnExit() async {
    if (!route.hasMiddleware) {
      return;
    }
    for (var middle in route.route.middleware!) {
      await middle.onExit();
    }
  }

  Future scheduleOnExited() async {
    if (!route.hasMiddleware) return;

    WidgetsBinding.instance.addPostFrameCallback((timeStamp) {
      for (var middle in route.route.middleware!) {
        middle.onExited();
      }
    });
  }

  Future runOnMatch() async {
    if (!route.hasMiddleware) {
      return;
    }
    for (var middle in route.route.middleware!) {
      await middle.onMatch();
    }
  }

  Future<bool> runCanPop() async {
    if (!route.hasMiddleware) {
      return true;
    }
    for (var middle in route.route.middleware!) {
      if (!await middle.canPop()) {
        return false;
      }
    }
    return true;
  }
}

==> qlevar_router-1.8.1.tar.gz: lib/src/controllers/middleware_controller.dart <==
import 'package:flutter/material.dart';

import '../../qlevar_router.dart';
import '../routes/qroute_internal.dart';

class MiddlewareController {
  final QRouteInternal route;
  MiddlewareController(this.route);

  Future<String?> runRedirect() async {
    final path = route.getLastActivePath();
    for (var middle in route.route.middleware!) {
      final result = await middle.redirectGuard(path);
      if (result != null) {
        return result;
      }
    }
    return null;
  }

  Future<QNameRedirect?> runRedirectName() async {
    final path = route.getLastActivePath();
    for (var middle in route.route.middleware!) {
      final result = await middle.redirectGuardToName(path);
      if (result != null) {
        return result;
      }
    }
    return null;
  }

  Future runOnEnter() async {
    if (!route.hasMiddleware) {
      return;
    }
    for (var middle in route.route.middleware!) {
      await middle.onEnter();
    }
  }

  Future runOnExit() async {
    if (!route.hasMiddleware) {
      return;
    }
    for (var middle in route.route.middleware!) {
      await middle.onExit();
    }
  }

  Future scheduleOnExited() async {
    if (!route.hasMiddleware) return;

    WidgetsBinding.instance.addPostFrameCallback((_) {
      WidgetsBinding.instance.endOfFrame.then((_) {
        for (var middle in route.route.middleware!) {
          middle.onExited();
        }
      });
    });
  }

  Future runOnMatch() async {
    if (!route.hasMiddleware) {
      return;
    }
    for (var middle in route.route.middleware!) {
      await middle.onMatch();
    }
  }

  Future<bool> runCanPop() async {
    if (!route.hasMiddleware) {
      return true;
    }
    for (var middle in route.route.middleware!) {
      if (!await middle.canPop()) {
        return false;
      }
    }
    return true;
  }
}
